<?php
// Load custom theme options
if( is_admin() ) require_once get_template_directory() . '/library/theme-options.php';
$scrapbook_options = get_option('scrapbook_theme_options');

if ( ! function_exists( 'scrapbook_setup' ) ):
function scrapbook_setup() {

	// Load language files
	load_theme_textdomain( 'scrapbook', TEMPLATEPATH . '/langs' );
	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/langs/$locale.php";
	if ( is_readable( $locale_file ) ) require_once( $locale_file );

	if ( ! isset( $content_width ) ) $content_width = 720;

	// Add theme support
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'custom-attachment-image', 720, 720 );
	add_theme_support( 'automatic-feed-links' );

	// Get the post thumbnail dimensions from Settings/Media
	set_post_thumbnail_size( get_option('thumbnail_size_w'), get_option('thumbnail_size_h') ); // box (proportional) resize mode

	// Add support for custom background
	add_custom_background();

	// Add support for custom editor style
	add_editor_style();


	// Header customisation/
	define('HEADER_IMAGE_WIDTH', apply_filters( 'scrapbook_header_image_width',1100 ) );
	define('HEADER_IMAGE_HEIGHT', apply_filters( 'scrapbook_header_image_height', 100 ) );
	define('HEADER_IMAGE', apply_filters( 'scrapbook_header_image', get_stylesheet_directory_uri() . '/images/flowers.jpg') );
	define('HEADER_TEXTCOLOR', apply_filters( 'scrapbook_header_color', '776963') );
	define ('BACKGROUND_COLOR', apply_filters('scrapbook_background_color', 'fff') );
	define ('BACKGROUND_IMAGE', apply_filters( 'scrapbook_background_image', '') );

}
endif;
add_action( 'after_setup_theme', 'scrapbook_setup' );

// Load accordian menu
require (get_template_directory() . '/library/accordian.php');

// Load thickbox
if( !is_admin() && (!isset($scrapbook_options['thickbox']) || $scrapbook_options['thickbox'] == 'yes' ) ) require_once get_template_directory() . '/library/thickbox.php';

// Output custom head CSS
if (!function_exists( 'scrapbook_style' ) ) :
function scrapbook_style() {
	if ( function_exists( 'scrapbook_custom_header_style' ) ) scrapbook_custom_header_style();
}
endif;
add_action( 'wp_head', 'scrapbook_style' );

// Register sidebar(s)
if ( !function_exists( 'scrapbook_widgets_init' )) :
function scrapbook_widgets_init() {
	register_sidebar(array(
		'name'=> 'Scrapbook Upper',
		'id' => 'scrapbook-upper',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name'=> 'Scrapbook Sidebar',
		'id' => 'scrapbook-main',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name'=> 'Scrapbook Lower',
		'id' => 'scrapbook-lower',
		'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
}
endif;
add_action( 'widgets_init', 'scrapbook_widgets_init' );

// add custom menu support
if ( function_exists( 'register_nav_menu' ) && !function_exists( 'scrapbook_register_menus' )) :
function scrapbook_register_menus() {
	register_nav_menu( 'primary', __( 'Primary', 'scrapbook' ) );
}
add_action( 'init', 'scrapbook_register_menus' );
endif;

if (!function_exists( 'scrapbook_menu_callback' ) ):
function scrapbook_menu_callback() {
if( get_option( 'show_on_front') == 'page' ) $exclude = '&exclude=' . get_option('page_on_front');
else $exclude = '';
if ( !dynamic_sidebar('scrapbook-main') ) : 	?>
<h3 class="pages"><?php _e('Pages','scrapbook');?></h3>
<ul class="pages default"><?php wp_list_pages('title_li=' . $exclude); ?></ul>

<h3 class="recent"><?php _e('Recent Entries','scrapbook');?></h3>
<ul class="recent default"><?php wp_get_archives('type=monthly&limit=6'); ?></ul>

<h3 class="categories"><?php _e('Categories','scrapbook');?></h3>
<ul class="categories default"><?php wp_list_categories('title_li=');?></ul>

<h3 class="archives"><?php _e('Archives','scrapbook');?></h3>
<ul class="archives default"><?php wp_get_archives('type=yearly&show_post_count=0'); ?></ul>

<h3 class="links"><?php _e('Links','scrapbook');?></h3>
<ul class="links"><?php wp_list_bookmarks('title_li='); ?></ul>
<?php endif;?>
<?php
}
endif;

// Set up a proper &hellip;for post extracts
if ( !function_exists( 'scrapbook_proper_hellip' ) ) :
function scrapbook_proper_hellip($more) {
	return '&hellip;';
}
endif;
add_filter('excerpt_more', 'scrapbook_proper_hellip');

// Create decent attachment links
if ( !function_exists( 'scrapbook_attachment_link' ) ) :
function scrapbook_attachment_link($id) {
	// grab file extension
	$bits = explode('.',get_attached_file($id));
	$ext = '.'.$bits[count($bits)-1].' format';
	// get the icon link
	$icon_link = wp_get_attachment_link($id,'thumbnail',false,true);
	// get the text link
	$text_link = wp_get_attachment_link($id,'',false,false);
	// get the filesize in kilobytes
	if(@filesize(get_attached_file($id))) {
		 $filesize = ceil(filesize(get_attached_file($id))/1024).'K';
		 return $icon_link. ' '.$text_link.' <small>('.$ext.' '.$filesize.')</small>';
	}
	else return $icon_link. ' '.$text_link.' <small>('.$ext.')</small>';
}
endif;

// remove gallery css
if ( !function_exists( 'scrapbook_remove_gallery_css' ) ) :
function scrapbook_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
endif;
add_filter( 'gallery_style', 'scrapbook_remove_gallery_css' );

// Make sure we always have a post/page title
if ( !function_exists( 'scrapbook_correct_missing_title' ) ) :
function scrapbook_correct_missing_title( $title ) {
	if ( $title == '' ) $title = __('No Title','scrapbook');
	return $title;
}
endif;
add_filter( 'the_title','scrapbook_correct_missing_title' );

// Return page tree
if ( !function_exists( 'scrapbook_page_tree' ) ) :
function scrapbook_page_tree($this_page) {
	$pagelist = '';
	if( !$this_page->post_parent ) {
		$children = wp_list_pages('title_li=&child_of='.$this_page->ID.'&echo=0');
		if( $children ) {
			$pagelist .= '<li class="current_page_item"><a href="'.  get_page_link($this_page->ID) .'">' . $this_page->post_title . '</a>';
			$pagelist .= '<ul>' . $children . '</ul>';
			$pagelist .= '</li>';
		}
	}
	elseif( $this_page->ancestors ) {
		// get the top ID of this page. Page ids DESC so top level ID is the last one
		$ancestor = end($this_page->ancestors);
		$pagelist .= wp_list_pages('title_li=&include='.$ancestor.'&echo=0');
		$pagelist = str_replace('</li>', '', $pagelist);
		$pagelist .= '<ul>' . wp_list_pages('title_li=&child_of='.$ancestor.'&echo=0') .'</ul></li>';
	}
	return $pagelist;
}
endif;

// Get archive date
if ( !function_exists( 'scrapbook_get_archive_date' ) ) :
function scrapbook_get_archive_date() {
	if (is_day()) $this_archive = get_the_time('j F Y');
	elseif (is_month()) $this_archive = get_the_time('F Y');
	else $this_archive = get_the_time('Y');
	return $this_archive;
}
endif;

// Amend comment form fields
if ( !function_exists( 'scrapbook_comment_fields' ) ) :
	function scrapbook_comment_fields($fields) {
		$commenter = wp_get_current_commenter();
		$req = get_option('require_name_email');
		if( $req ) $reqd = '<span class="required">' . __('*', 'scrapbook') . '</span>';

		$fields['author'] = '<p class="comment-form-author"><label class="text" for="author">' . __( 'Name', 'scrapbook' ) . $reqd . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>';

		$fields['email'] = '<p class="comment-form-email"><label class="text" for="email">' . __( 'Email', 'scrapbook' ) . $reqd . '</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" />' . '</p>';

		$fields['url']   = '<p class="comment-form-url"><label class="text" for="url">' . __( 'Website', 'scrapbook') . '</label>' . '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

		return $fields;
	}
endif;
add_filter('comment_form_default_fields','scrapbook_comment_fields');

// Amend comment form arguments
if ( ! function_exists( 'scrapbook_comment_form_args' ) ) :
	function scrapbook_comment_form_args($user_identity, $post_id, $req) {
		$args = array(
			'comment_notes_before' => '<p class="comment-notes"><label for="email">' . ( $req ? __( ' Required fields are marked ', 'scrapbook') . '<span class="required">' . __('*', 'scrapbook') . '</span><br />' : '' ) . __( 'Your email address will <em>never</em> be published or shared.' ) . '</label></p>',

			'logged_in_as' => '<p class="logged-in-as"><label for="comment">' . sprintf( __( 'Logged in as <a href="%s">%s</a>. <a href="%s" title="Log out of this account">Log out?</a></label></p>' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ),

			'comment_notes_after' => '',

			'comment_field' => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8"></textarea></p>',
			'label_submit'=>'Submit Reply'
		);
		return $args;
	}
endif;

// output header image & text CSS
if ( !function_exists( 'scrapbook_custom_header_style' ) ) :
	function scrapbook_custom_header_style() {
		echo '<style type="text/css" media="screen,print">'."\n";
		if( get_header_image() != '' ) echo '#blogtitle {background-image:url(' . get_header_image() . ');}';
		if( get_header_textcolor() == 'blank' ) echo '#blogtitle h1,#blogtitle h1 a {position:absolute;top:-5000px;left:-5000px;}';
		else echo '#blogtitle h1,#blogtitle h1 a {color:#' . get_header_textcolor() . ';}';
		echo "\n</style>\n\n";
	}
endif;

// Style header customisation in the Admin area
if ( !function_exists( 'scrapbook_admin_header_style' ) ) :
function scrapbook_admin_header_style() {
?>
<style type="text/css">
#headimg {
	background-color:#fff;
	background-position:left top;
	background-repeat:no-repeat;
}
#headimg,#headimg h1 {
	margin:0;
	padding:0;
	height:100px;
	text-align:right;
	color:#776963;
}
#headimg #desc {
	display:none !important;
}
#headimg a {
	text-decoration:none;
}
#headimg a:hover,#headimg a:active,#headimg a:focus {
	text-decoration:underline;
}
#headimg h1 {
	padding-top:10px;
	font-size:3em;
	font-weight:normal;
	font-style:italic;
	letter-spacing:0.1em;
	font-family:georgia,palatino,'times new roman',serif;
}
</style>
<?php
}
endif;
add_custom_image_header('', 'scrapbook_admin_header_style');

