<?php
// THEME OPTIONS: Scrapbook

// Set options array
 $all_scrapbook_theme_options = array(
	'thickbox' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Yes', 'scrapbook' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'No', 'scrapbook' )
			)
		)
	),
	'exif_display' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Yes', 'scrapbook' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'No', 'scrapbook' )
			)
		)
	)
);

// White list theme options
function scrapbook_theme_options_init() {
	register_setting( 'scrapbook_options', 'scrapbook_theme_options', 'scrapbook_theme_options_validate' );
}
add_action( 'admin_init', 'scrapbook_theme_options_init' );

// Add theme options page
function scrapbook_theme_options_add_page() {
	add_theme_page( __( 'Theme Options' ), __( 'Theme Options' ), 'edit_theme_options', 'theme_options', 'scrapbook_theme_options_do_page' );
}
add_action('admin_menu', 'scrapbook_theme_options_add_page');

// Load theme options stylesheet
function scrapbook_add_theme_options_style() {
	$css_file = get_template_directory() . '/library/theme-options.css';
	$css_url = get_template_directory_uri() . '/library/theme-options.css';
	if ( file_exists($css_file) ) {
		wp_register_style('theme_options_style', $css_url, '', '', 'screen');
	}
}
function scrapbook_enqueue_theme_options_style() {
	wp_enqueue_style('theme_options_style');
}
add_action('admin_init', 'scrapbook_add_theme_options_style');
add_action('admin_print_styles', 'scrapbook_enqueue_theme_options_style');

// Theme options form
function scrapbook_theme_options_do_page() {
	global  $all_scrapbook_theme_options;
	if ( ! isset( $_REQUEST['updated'] ) ) $_REQUEST['updated'] = false;
	?>

	<div class="wrap">
	<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Options', 'scrapbook') . "</h2>"; ?>

	<?php if ( false !== $_REQUEST['updated'] ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your eShop Theme options have been saved', 'scrapbook'); ?></strong></p></div>
	<?php endif; ?>

	<?php include_once 'donate.php';?>

	<form method="post" action="options.php" id="scrapbook_options"><div>
	<?php settings_fields( 'scrapbook_options' ); ?>
	<?php $stored_options = get_option('scrapbook_theme_options');?>

	<fieldset>
	<legend><?php _e('Enable Thickbox on image pages?','scrapbook'); ?></legend>
	<label for="thickbox_no"><small><?php _e('Select "No" if you intend to use a lightbox or shadowbox plugin.', 'scrapbook');?></small></label><br />
	<?php $option_name = 'thickbox';
	scrapbook_theme_options_sort( $all_scrapbook_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Display EXIF data on image pages?','scrapbook'); ?></legend>
	<label for="exif_display_yes"><small><?php _e('Data stored in photographs such as camera, aperture, focal length etc.', 'scrapbook');?></small></label><br />
	<?php $option_name = 'exif_display';
	scrapbook_theme_options_sort( $all_scrapbook_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'scrapbook') ?>" /></p>

	</div></form>
</div>
	<?php
}

// sort inputs for display
function scrapbook_theme_options_sort($option_input, $stored_options, $name) {
	switch ($option_input['type']) {
		case 'radio':
		scrapbook_theme_options_do_radio($option_input['options'], $stored_options, $name, $option_input['default']);
		break;

		case 'text':
		scrapbook_theme_options_do_text($option_input, $stored_options, $name);
		break;

		case 'select':
		scrapbook_theme_options_do_select($option_input, $stored_options, $name, $option_input['default']);
		break;

		default:
		break;
	}
}

// Radio button display
function scrapbook_theme_options_do_radio($radio_options, $stored_options, $name, $default) {
	foreach ( $radio_options as $option ) {
		if ( !isset( $stored_options[$name] ) ) $stored_options[$name] = $default;?>
		<label class="description radio" for="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>"><input type="radio" id="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>" name="scrapbook_theme_options[<?php echo $name;?>]" value="<?php esc_attr_e( $option['value'] ); ?>" <?php checked( $stored_options[$name] , $option['value'] ); ?> /> <?php echo $option['label']; ?></label>
		<?php
	}
}

// Text input display
function scrapbook_theme_options_do_text($setting, $stored_options, $name) {
	if( isset( $stored_options[$name] ) ) {
		if( $setting['numeric'] == 1 ) {
			if( ctype_digit( $stored_options[$name] ) ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
		else {
			if( $stored_options[$name] != '' ) $current_value = wp_filter_nohtml_kses($stored_options[$name]);
			else $current_value = $setting['default'];
		}
	}
	else $current_value = $setting['default'];
	?>
	<label class="description text" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <input type="text" id="<?php echo $name;?>" name="scrapbook_theme_options[<?php echo $name;?>]" size="<?php echo $setting['size'];?>" maxlength="<?php echo $setting['maxlength'];?>" value="<?php echo $current_value;?>" />
	<?php
}

// Select display
function scrapbook_theme_options_do_select($setting, $stored_options, $name) {
	?>
	<label class="description select" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <select name="scrapbook_theme_options[<?php echo $name;?>]" id="<?php echo $name;?>">
	<?php
	foreach( $setting['options'] as $option ) {
		if( !isset( $selected ) ) $selected = '';
		if( isset( $stored_options[$name] ) ) {
			if( $stored_options[$name] == $option['value'] ) $selected = ' selected="selected"';
			else $selected = '';
		}
		else{
			if( $option['value']  ==  $setting['default'] ) $selected = ' selected="selected"';
			else $selected = '';
		}?>
		<option value="<?php echo $option['value'];?>"<?php echo $selected;?>><?php echo $option['label'];?></option><?php
	}
	echo "</select>\n";
}

// Sanitize and validate inputs
function scrapbook_theme_options_validate( $input ) {
	$new_input = array();
	global $all_scrapbook_theme_options;
	$theme_option_names = array_keys($all_scrapbook_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $all_scrapbook_theme_options[$theme_option_name]['type'];
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $all_scrapbook_theme_options[$theme_option_name]['default'];
		switch ($option_type) {

			case 'radio':
			// Default = yes
			if( $all_scrapbook_theme_options[$theme_option_name]['default'] == 'yes' ) $new_input[$theme_option_name] = ( $input[$theme_option_name] == 'yes' ? 'yes' : 'no' );

			case 'text':
			// Numeric
			if( $all_scrapbook_theme_options[$theme_option_name]['numeric'] == 1 &&  !ctype_digit( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $all_scrapbook_theme_options[$theme_option_name]['default'];
			// Plain text
			else $new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			case 'select':
			if( $input[$theme_option_name] == '' ) $new_input[$theme_option_name] = $all_scrapbook_theme_options[$theme_option_name]['default'];
			else {
				foreach(  $all_scrapbook_theme_options[$theme_option_name]['options'] as $valid_option ) {
					if( $input[$theme_option_name] == $valid_option['value'] )  $new_input[$theme_option_name] = $input[$theme_option_name];
				}
			}
			break;

			case 'textarea':
			// Plain text
			$new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
	}
	return $new_input;
}
